@@ -179,12 +179,12 @@ class PreviewCameraX(PreviewCommon, CommonGestures):
 
     # CommonGestures Touch Events
     # tap for focus
-    def cg_tap(self, touch, x, y):
+    def cgb_primary(self, touch, x, y):
         if self._camera and self.enable_focus_gesture:
             self.focus(x, y)
 
     # pinch/spread for zoom
-    def cg_scale(self, touch0, touch1, scale, x, y):
+    def cgb_zoom(self, touch0, touch1, x, y, scale):
         if self._camera and self.enable_zoom_gesture:
             self.zoom_delta(scale)
 
